You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@storm.apache.org by sr...@apache.org on 2019/08/30 16:51:01 UTC

[storm] branch master updated: STORM-3500: Fix spelling error in property storm.blobstore.dependency.jar.upload.chuck.size.bytes

This is an automated email from the ASF dual-hosted git repository.

srdo pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/storm.git


The following commit(s) were added to refs/heads/master by this push:
     new 405c90b  STORM-3500: Fix spelling error in property storm.blobstore.dependency.jar.upload.chuck.size.bytes
     new 2c095ee  Merge pull request #3118 from srdo/STORM-3500
405c90b is described below

commit 405c90ba16bb886ae9727b65682ad902c8f2fb0b
Author: Stig Rohde Døssing <sr...@apache.org>
AuthorDate: Tue Aug 27 22:28:50 2019 +0200

    STORM-3500: Fix spelling error in property storm.blobstore.dependency.jar.upload.chuck.size.bytes
---
 conf/defaults.yaml                                                  | 2 +-
 storm-client/src/jvm/org/apache/storm/Config.java                   | 6 +++---
 .../src/jvm/org/apache/storm/dependency/DependencyUploader.java     | 6 +++---
 3 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/conf/defaults.yaml b/conf/defaults.yaml
index 1a17e52..e555ac8 100644
--- a/conf/defaults.yaml
+++ b/conf/defaults.yaml
@@ -144,7 +144,7 @@ nimbus.blobstore.class: "org.apache.storm.blobstore.LocalFsBlobStore"
 nimbus.blobstore.expiration.secs: 600
 
 storm.blobstore.inputstream.buffer.size.bytes: 65536
-storm.blobstore.dependency.jar.upload.chuck.size.bytes: 1048576
+storm.blobstore.dependency.jar.upload.chunk.size.bytes: 1048576
 client.blobstore.class: "org.apache.storm.blobstore.NimbusBlobStore"
 storm.blobstore.replication.factor: 3
 # For secure mode we would want to change this config to true
diff --git a/storm-client/src/jvm/org/apache/storm/dependency/DependencyUploader.java b/storm-client/src/jvm/org/apache/storm/dependency/DependencyUploader.java
index 1f6b4f4..85ab835 100644
--- a/storm-client/src/jvm/org/apache/storm/dependency/DependencyUploader.java
+++ b/storm-client/src/jvm/org/apache/storm/dependency/DependencyUploader.java
@@ -48,11 +48,11 @@ public class DependencyUploader {
 
     private final Map<String, Object> conf;
     private ClientBlobStore blobStore;
-    private int uploadChuckSize;
+    private final int uploadChunkSize;
 
     public DependencyUploader() {
         conf = Utils.readStormConfig();
-        this.uploadChuckSize = ObjectReader.getInt(conf.get(Config.STORM_BLOBSTORE_DEPENDENCY_JAR_UPLOAD_CHUCK_SIZE_BYTES), 1024 * 1024);
+        this.uploadChunkSize = ObjectReader.getInt(conf.get(Config.STORM_BLOBSTORE_DEPENDENCY_JAR_UPLOAD_CHUNK_SIZE_BYTES), 1024 * 1024);
     }
 
     public void init() {
@@ -164,7 +164,7 @@ public class DependencyUploader {
             try {
                 blob = getBlobStore().createBlob(key, new SettableBlobMeta(acls));
                 try (InputStream in = Files.newInputStream(dependency.toPath())) {
-                    IOUtils.copy(in, blob, this.uploadChuckSize);
+                    IOUtils.copy(in, blob, this.uploadChunkSize);
                 }
                 blob.close();
                 blob = null;
diff --git a/storm-client/src/jvm/org/apache/storm/Config.java b/storm-client/src/jvm/org/apache/storm/Config.java
index 5d89fc9..b46c112 100644
--- a/storm-client/src/jvm/org/apache/storm/Config.java
+++ b/storm-client/src/jvm/org/apache/storm/Config.java
@@ -1418,12 +1418,12 @@ public class Config extends HashMap<String, Object> {
     @IsInteger
     public static final String STORM_BLOBSTORE_INPUTSTREAM_BUFFER_SIZE_BYTES = "storm.blobstore.inputstream.buffer.size.bytes";
     /**
      * What chuck size to use for storm client to upload dependency jars.
      */
     @IsPositiveNumber
     @IsInteger
-    public static final String STORM_BLOBSTORE_DEPENDENCY_JAR_UPLOAD_CHUCK_SIZE_BYTES =
-            "storm.blobstore.dependency.jar.upload.chuck.size.bytes";
+    public static final String STORM_BLOBSTORE_DEPENDENCY_JAR_UPLOAD_CHUNK_SIZE_BYTES =
+            "storm.blobstore.dependency.jar.upload.chunk.size.bytes";
     /**
      * FQCN of a class that implements {@code ISubmitterHook} @see ISubmitterHook for details.
      */
@@ -1418,12 +1418,12 @@ public class Config extends HashMap<String, Object> {
     public static final String STORM_BLOBSTORE_INPUTSTREAM_BUFFER_SIZE_BYTES = "storm.blobstore.inputstream.buffer.size.bytes";
     /**
-     * What chuck size to use for storm client to upload dependency jars.
+     * What chunk size to use for storm client to upload dependency jars.
      */
     @IsPositiveNumber